@@ -8,7 +8,7 @@ from typing import Dict
 
 import regex as re
 
-from ..urdu_characters import URDU_ALL_CHARACTERS, URDU_PUNCTUATIONS, URDU_DIACRITICS
+from urduhack.urdu_characters import URDU_ALL_CHARACTERS, URDU_PUNCTUATIONS, URDU_DIACRITICS
 
 # Contains wrong Urdu characters mapping to correct characters
 CORRECT_URDU_CHARACTERS: Dict = {'آ': ['ﺁ', 'ﺂ'],
@@ -93,6 +93,10 @@ def normalize_characters(text: str) -> str:
         text (str): raw ``urdu`` text
     Returns:
         str: returns a ``str`` object containing normalized text.
+    Examples:
+        >>> from urduhack.normalization import normalize_characters
+        >>> text = normalize_characters("پاکستان ﻤﯿﮟ وسائل کی کوئی کمی نہیں ﮨﮯ۔")
+        پاکستان ﻤﯿﮟ وسائل کی کوئی کمی نہیں ﮨﮯ۔
     """
     return text.translate(_TRANSLATOR)
 
@@ -223,3 +227,53 @@ def normalize(text: str) -> str:
     text = remove_diacritics(text)
     text = english_characters_space(text)
     return text
+
+
+ENG_URDU_DIGITS_MAP: Dict = {
+    '0': ['۰'],
+    '1': ['۱'],
+    '2': ['۲'],
+    '3': ['۳'],
+    '4': ['۴'],
+    '5': ['۵'],
+    '6': ['۶'],
+    '7': ['۷'],
+    '8': ['۸'],
+    '9': ['۹']
+}
+
+_ENG_DIGITS_TRANSLATOR = {}
+for key, value in ENG_URDU_DIGITS_MAP.items():
+    _ENG_DIGITS_TRANSLATOR.update(dict.fromkeys(map(ord, value), key))
+
+URDU_ENG_DIGITS_MAP: Dict = {
+    '۰': ['0'],
+    '۱': ['1'],
+    '۲': ['2'],
+    '۳': ['3'],
+    '۴': ['4'],
+    '۵': ['5'],
+    '۶': ['6'],
+    '۷': ['7'],
+    '۸': ['8'],
+    '۹': ['9']
+}
+
+_URDU_DIGITS_TRANSLATOR = {}
+for key, value in URDU_ENG_DIGITS_MAP.items():
+    _URDU_DIGITS_TRANSLATOR.update(dict.fromkeys(map(ord, value), key))
+
+
+def replace_digits(text: str, with_eng: bool = True) -> str:
+    """
+    Replace urdu digits with English digits and vice versa
+
+    Args:
+        text (str): urdu text string
+        with_eng (bool): Boolean to convert digits from one language to other
+    Returns:
+        Text string with replaced digits
+    """
+    if with_eng:
+        return text.translate(_ENG_DIGITS_TRANSLATOR)
+    return text.translate(_URDU_DIGITS_TRANSLATOR)
