@@ -6,10 +6,10 @@ Sentiment Analysis Module
 import numpy as np
 from ._backend._sentiment import predict_pipeline, load_models
 
-_model, _tokenizer = load_models()
+_MODEL, _TOKENIZER = load_models()
 
 
-def predict_label(text: str, index2label: dict = {0: "Negative", 1: "Positive"}):
+def predict_label(text: str, index2label: dict = {0: "Negative", 1: "Positive"}) -> str:
     """
     Predicts sentiment label
 
@@ -19,12 +19,12 @@ def predict_label(text: str, index2label: dict = {0: "Negative", 1: "Positive"})
     Returns:
          Any of Positive, Negative or Neutral label
     """
-    predictions = predict_pipeline(text=text, model=_model, tokenizer=_tokenizer)
+    predictions = predict_pipeline(text=text, model=_MODEL, tokenizer=_TOKENIZER)
     sentiment_id = np.argmax(predictions)
     return index2label[sentiment_id]
 
 
-def predict_id(text: str):
+def predict_id(text: str) -> float:
     """
     Predict sentiment id
     Args:
@@ -32,5 +32,5 @@ def predict_id(text: str):
     Returns:
         0 if Negative and 1 if Positive
     """
-    predictions = predict_pipeline(text=text, model=_model, tokenizer=_tokenizer)
-    return np.argmax(predictions)
\ No newline at end of file
+    predictions = predict_pipeline(text=text, model=_MODEL, tokenizer=_TOKENIZER)
+    return np.argmax(predictions)
